@@ -864,6 +864,45 @@ sub draw_form_field_string {
 	drawer_call ('draw_form_field_string', @_);
 }
 
+################################################################################
+
+=head1 draw_form_field_datetime
+
+    'datetime' (  DHTML  http://dynarch.com/mishoo/calendar.epl).   - C<draw_form>.
+
+=head2 
+
+=over
+
+=item name
+
+ CGI-      C<$data>.
+
+=item label
+
+ 
+
+=item size
+
+  C<size>  C<maxlength>
+
+=item no_time
+
+  .
+
+=item format
+
+  (  .  ,  download).
+
+=back
+
+=cut
+
+################################################################################
+
+sub draw_form_field_datetime {
+	drawer_call ('draw_form_field_datetime', @_);
+}
 
 ################################################################################
 
